@@ -1636,7 +1636,7 @@ class VariableClBuilderBinhostStableSet(
     opt = ["--stable"]
 
     def init(self):
-        self.label = _("Check the repositories integrity")
+        self.label = _("Use only stable updates")
         self.help = _("use only stable updates")
 
     def prepare_vars(self, dvbl):
